==> webkit2gtk_2.36.0.orig.tar.xz: webkitgtk-2.36.0/Source/WebKit/GPUProcess/media/AudioTrackPrivateRemoteConfiguration.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(GPU_PROCESS)

#include "TrackPrivateRemoteConfiguration.h"
#include <WebCore/AudioTrackPrivate.h>

namespace WebKit {

struct AudioTrackPrivateRemoteConfiguration : TrackPrivateRemoteConfiguration {
    bool enabled;
    WebCore::AudioTrackPrivate::Kind kind { WebCore::AudioTrackPrivate::Kind::None };
    WebCore::PlatformAudioTrackConfiguration trackConfiguration;

    template<class Encoder>
    void encode(Encoder& encoder) const
    {
        TrackPrivateRemoteConfiguration::encode(encoder);
        encoder << enabled;
        encoder << kind;
        encoder << trackConfiguration;
    }

    template <class Decoder>
    static bool WARN_UNUSED_RETURN decode(Decoder& decoder, AudioTrackPrivateRemoteConfiguration& configuration)
    {
        return TrackPrivateRemoteConfiguration::decode(decoder, configuration)
            && decoder.decode(configuration.enabled)
            && decoder.decode(configuration.kind)
            && decoder.decode(configuration.trackConfiguration);
    }
};

} // namespace WebKit

#endif

==> webkit2gtk_2.40.5.orig.tar.xz: webkitgtk-2.40.5/Source/WebKit/GPUProcess/media/AudioTrackPrivateRemoteConfiguration.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)

#include "TrackPrivateRemoteConfiguration.h"
#include <WebCore/AudioTrackPrivate.h>

namespace WebKit {

struct AudioTrackPrivateRemoteConfiguration : TrackPrivateRemoteConfiguration {
    bool enabled;
    WebCore::AudioTrackPrivate::Kind kind { WebCore::AudioTrackPrivate::Kind::None };
    WebCore::PlatformAudioTrackConfiguration trackConfiguration;

    template<class Encoder>
    void encode(Encoder& encoder) const
    {
        TrackPrivateRemoteConfiguration::encode(encoder);
        encoder << enabled;
        encoder << kind;
        encoder << trackConfiguration;
    }

    template <class Decoder>
    static bool WARN_UNUSED_RETURN decode(Decoder& decoder, AudioTrackPrivateRemoteConfiguration& configuration)
    {
        return TrackPrivateRemoteConfiguration::decode(decoder, configuration)
            && decoder.decode(configuration.enabled)
            && decoder.decode(configuration.kind)
            && decoder.decode(configuration.trackConfiguration);
    }
};

} // namespace WebKit

#endif // ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
